@@ -7,7 +7,7 @@
 
 #include "compositor.h"
 #include "display.h"
-#include "mutter-plugin-manager.h"
+#include "meta-plugin-manager.h"
 #include <clutter/clutter.h>
 
 typedef struct _MetaCompScreen MetaCompScreen;
@@ -23,7 +23,7 @@ struct _MetaCompositor
 
   ClutterActor   *shadow_src;
 
-  MutterPlugin   *modal_plugin;
+  MetaPlugin     *modal_plugin;
 
   gboolean        show_redraw : 1;
   gboolean        debug       : 1;
@@ -35,6 +35,7 @@ struct _MetaCompScreen
   MetaScreen            *screen;
 
   ClutterActor          *stage, *window_group, *overlay_group;
+  ClutterActor          *background_actor;
   ClutterActor		*hidden_group;
   GList                 *windows;
   GHashTable            *windows_by_xid;
@@ -45,24 +46,24 @@ struct _MetaCompScreen
 
   gint                   switch_workspace_in_progress;
 
-  MutterPluginManager *plugin_mgr;
+  MetaPluginManager *plugin_mgr;
 };
 
-void mutter_switch_workspace_completed (MetaScreen    *screen);
-void mutter_set_stage_input_region     (MetaScreen    *screen,
-                                        XserverRegion  region);
-void mutter_empty_stage_input_region   (MetaScreen    *screen);
+void meta_switch_workspace_completed (MetaScreen    *screen);
+void meta_set_stage_input_region     (MetaScreen    *screen,
+                                      XserverRegion  region);
+void meta_empty_stage_input_region   (MetaScreen    *screen);
 
-gboolean mutter_begin_modal_for_plugin (MetaScreen       *screen,
-                                        MutterPlugin     *plugin,
-                                        Window            grab_window,
-                                        Cursor            cursor,
-                                        MetaModalOptions  options,
-                                        guint32           timestamp);
-void     mutter_end_modal_for_plugin   (MetaScreen       *screen,
-                                        MutterPlugin     *plugin,
-                                        guint32           timestamp);
+gboolean meta_begin_modal_for_plugin (MetaScreen       *screen,
+                                      MetaPlugin       *plugin,
+                                      Window            grab_window,
+                                      Cursor            cursor,
+                                      MetaModalOptions  options,
+                                      guint32           timestamp);
+void     meta_end_modal_for_plugin   (MetaScreen       *screen,
+                                      MetaPlugin       *plugin,
+                                      guint32           timestamp);
 
-void mutter_check_end_modal (MetaScreen *screen);
+void meta_check_end_modal (MetaScreen *screen);
 
 #endif /* META_COMPOSITOR_PRIVATE_H */
